##  Updating Code
To update custom code, choose Go to Code on the configuration details page. This opens the corresponding calculation or webhook page where you can edit the code in its dedicated editor. You can't edit code directly in the Managed Code section.
For automations, the Go to Code option is currently not supported.
